==> hboard-1.0-rc1.tar.gz: hboard/install_3.php <==
<?php

/* EtchiBoard Version 1.0
     install_3.php
     http://etchibbs.kldp.net */

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

/* db ó */

if(file_exists("dbconn.php")) {
echo "<html>\n<body>\n\n"
    ."<script language=\"JavaScript\" type=\"\">\n"
    ."alert(\"̹ ġ Ϸ Դϴ.\\nٽ ġϽ÷ dbconn.php  Ͻ , ٽ õϼ.\");\n"
    ."</script>\n\n</body>\n</html>";
}

else {

 $mysql_connect = mysql_connect($mysql_hostname, $mysql_user, $mysql_password); // ϴ ..

 if(!$mysql_connect) {
  echo "mysql connect error";
 }

 else if(!mysql_select_db($mysql_db)) {
  echo "mysql db select error";
  mysql_close($mysql_connect);
 }

 else {

  /* ͺ̽  (dbconn.php)  */
  $file_open = fopen("dbconn.php", "w");
   fwrite($file_open, "<?php\n");
   fwrite($file_open, $mysql_hostname ."\n");
   fwrite($file_open, $mysql_user ."\n");
   fwrite($file_open, $mysql_db ."\n");
   fwrite($file_open, $mysql_password ."\n");
   fwrite($file_open, "?>");
  fclose($file_open);

  mysql_select_db($mysql_db);
  $admin_passwd = crypt($admin_passwd, HB);
  mysql_query("insert into hboard_db_admin values('${admin_passwd}','frog_yellow',5,512000,'f','','','<font size=3><b>Welcome to EtchiBoard!</b></font>','','0','korean','0')");

 // 丮/  
 mkdir("db", 0707);
 mkdir("db/ico", 0777);
 mkdir("db/img", 0777);

 //  index.html  丮  
 $file_open = fopen("db/index.html", "w");
 fclose($file_open);
 copy("db/index.html", "db/ico/index.html");
 chmod("db/ico/index.html", 0777);
 copy("db/index.html", "db/img/index.html");
 chmod("db/img/index.html", 0777);

 // db ũ 
 if(!file_exists("db/img/dbinfo")) {
  $file_open = fopen("db/img/dbinfo", "w");
  fwrite($file_open, "[size]\n0");
  fclose($file_open);
  chmod("db/img/dbinfo", 0777);
 }

/* Ϸ! */
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<meta http-equiv="content-type" content="text/html; charset=ks_c_5601-1987">
<title>EtchiBoard Installation Wizard</title>
</head>

<body bgcolor="white" text="black" link="blue" vlink="purple" alink="red">
<table align="center" width="656" cellpadding="0" cellspacing="0">
    <tr>
        <td width="381" height="156">
            <table cellpadding="0" cellspacing="0" width="100%">
                <tr>
                    <td width="100%" bgcolor="#D7D7D7" valign="top" style="padding-top:15; padding-right:0; padding-bottom:0; padding-left:15;" height="160" background="img/installer_capt_bg.jpg">
                        <p><b><font face="Tahoma">Setup Completed<br></font></b><font face="Tahoma"><span style="font-size:9pt;"> <br>մϴ, 
                        Խ ġ ϷǾϴ.<br>Ȱ Խ  
                        , Ʒ  Ͽ ּ.<br><br> EtchiBoard 
                        Ͽ ּż մϴ. </span></font><span style="font-size:9pt;">:D</span></p>
                    </td>
                </tr>
            </table>
        </td>
        <td width="259" height="430" rowspan="3">
            <table cellpadding="0" cellspacing="0">
                <tr>
                    <td width="256">
                        <p><img src="img/install_char.jpg" width="279" height="480" border="0" alt="install_char.jpg"></p>
                    </td>
                </tr>
            </table>
        </td>
    </tr>
    <tr>
        <td width="381" height="233">
            <table align="center" cellpadding="0" cellspacing="0" width="357">
                <tr>
                    <td width="357" height="20" bgcolor="#F4F4F4">
                        <p><span style="font-size:9pt;">&nbsp;Խ ġ </span></p>
                    </td>
                </tr>
                <tr>
                    <td width="357" height="15">
                        <p align="center"><span style="font-size:9pt;">&nbsp;</span></p>
                    </td>
                </tr>
                <tr>
                    <td width="357" height="138">
                        <p><span style="font-size:9pt;">&nbsp; 
                         DB ̺ ͺ̽ Ǿϴ:<br> &nbsp;<font color="#003399">&nbsp;hboard_db_article 
                        (Խù )<br> &nbsp;&nbsp;hboard_db_comment (ǰ߱ 
                        )<br> &nbsp;&nbsp;hboard_db_admin (  
                        )</font><br>&nbsp;<br> &nbsp;Ʒ [<b>Ȯ</b>] 
                        ư ø Խ ̵մϴ.<br> &nbsp;Խ 
                        ̵ , ּ Էٿ ǥõǴ ּҸ<br> &nbsp;״ 
                        Ȩ &nbsp;ũ ֽø ˴ϴ.</span></p>
                    </td>
                </tr>
            </table>
            <p align="center"><span style="font-size:9pt;"><a href="list.php"><img src="img/install_complete.jpg" width="85" height="35" border="0" alt="ġ Ϸ"></a> 
            </span></p>
        </td>
    </tr>
    <tr>
        <td width="381" height="22">
            <p align="right"><span style="font-size:8pt;"><font face="Tahoma" color="#999999">EtchiBoard 
            Gallery System: by EtchiBBS Project.<br> http://etchibbs.kldp.net</font></span></p>
        </td>
    </tr>
</table>
</body>

</html>
<?php
mysql_close($mysql_connect);
 }
}
?>

==> hboard-1.0.2b.tar.gz: hboard/install_3.php <==
<?php

/* EtchiBoard Version 1.0
     install_3.php
     http://etchibbs.kldp.net */

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

/* db ó */

if(file_exists("dbconn.php")) {
echo "<html>\n<body>\n\n"
    ."<script language=\"JavaScript\" type=\"\">\n"
    ."alert(\"̹ ġ Ϸ Դϴ.\\nٽ ġϽ÷ dbconn.php  Ͻ , ٽ õϼ.\");\n"
    ."</script>\n\n</body>\n</html>";
}

else {

 $mysql_connect = mysql_connect($mysql_hostname, $mysql_user, $mysql_password); // ϴ ..

 if(!$mysql_connect) {
  echo "mysql connect error";
 }

 else if(!mysql_select_db($mysql_db)) {
  echo "mysql db select error";
  mysql_close($mysql_connect);
 }

 else {

  /* ͺ̽  (dbconn.php)  */
  $file_open = fopen("dbconn.php", "w");
   fwrite($file_open, "<?php\n");
   fwrite($file_open, $mysql_hostname ."\n");
   fwrite($file_open, $mysql_user ."\n");
   fwrite($file_open, $mysql_db ."\n");
   fwrite($file_open, $mysql_password ."\n");
   fwrite($file_open, "?>");
  fclose($file_open);

  mysql_select_db($mysql_db);
  $admin_passwd = crypt($admin_passwd, HB);
  mysql_query("insert into hboard_db_admin values('${admin_passwd}','frog_yellow',5,512000,'f','','','<font size=3><b>Welcome to EtchiBoard!</b></font>','','0','korean','0','','t','f')");

 // 丮/  
 mkdir("db", 0707);
 mkdir("db/ico", 0777);
 mkdir("db/img", 0777);

 //  index.html  丮  
 $file_open = fopen("db/index.html", "w");
 fclose($file_open);
 copy("db/index.html", "db/ico/index.html");
 chmod("db/ico/index.html", 0777);
 copy("db/index.html", "db/img/index.html");
 chmod("db/img/index.html", 0777);

 // db ũ 
 if(!file_exists("db/img/dbinfo")) {
  $file_open = fopen("db/img/dbinfo", "w");
  fwrite($file_open, "[size]\n0");
  fclose($file_open);
  chmod("db/img/dbinfo", 0777);
 }

/* Ϸ! */
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<meta http-equiv="content-type" content="text/html; charset=ks_c_5601-1987">
<title>EtchiBoard Installation Wizard</title>
</head>

<body bgcolor="white" text="black" link="blue" vlink="purple" alink="red">
<table align="center" width="656" cellpadding="0" cellspacing="0">
    <tr>
        <td width="381" height="156">
            <table cellpadding="0" cellspacing="0" width="100%">
                <tr>
                    <td width="100%" bgcolor="#D7D7D7" valign="top" style="padding-top:15; padding-right:0; padding-bottom:0; padding-left:15;" height="160" background="img/installer_capt_bg.jpg">
                        <p><b><font face="Tahoma">Setup Completed<br></font></b><font face="Tahoma"><span style="font-size:9pt;"> <br>մϴ, 
                        Խ ġ ϷǾϴ.<br>Ȱ Խ  
                        , Ʒ  Ͽ ּ.<br><br> EtchiBoard 
                        Ͽ ּż մϴ. </span></font><span style="font-size:9pt;">:D</span></p>
                    </td>
                </tr>
            </table>
        </td>
        <td width="259" height="430" rowspan="3">
            <table cellpadding="0" cellspacing="0">
                <tr>
                    <td width="256">
                        <p><img src="img/install_char.jpg" width="279" height="480" border="0" alt="install_char.jpg"></p>
                    </td>
                </tr>
            </table>
        </td>
    </tr>
    <tr>
        <td width="381" height="233">
            <table align="center" cellpadding="0" cellspacing="0" width="357">
                <tr>
                    <td width="357" height="20" bgcolor="#F4F4F4">
                        <p><span style="font-size:9pt;">&nbsp;Խ ġ </span></p>
                    </td>
                </tr>
                <tr>
                    <td width="357" height="15">
                        <p align="center"><span style="font-size:9pt;">&nbsp;</span></p>
                    </td>
                </tr>
                <tr>
                    <td width="357" height="138">
                        <p><span style="font-size:9pt;">&nbsp; 
                         DB ̺ ͺ̽ Ǿϴ:<br> &nbsp;<font color="#003399">&nbsp;hboard_db_article 
                        (Խù )<br> &nbsp;&nbsp;hboard_db_comment (ǰ߱ 
                        )<br> &nbsp;&nbsp;hboard_db_admin (  
                        )</font><br>&nbsp;<br> &nbsp;Ʒ [<b>Ȯ</b>] 
                        ư ø Խ ̵մϴ.<br> &nbsp;Խ 
                        ̵ , ּ Էٿ ǥõǴ ּҸ<br> &nbsp;״ 
                        Ȩ &nbsp;ũ ֽø ˴ϴ.</span></p>
                    </td>
                </tr>
            </table>
            <p align="center"><span style="font-size:9pt;"><a href="list.php"><img src="img/install_complete.jpg" width="85" height="35" border="0" alt="ġ Ϸ"></a> 
            </span></p>
        </td>
    </tr>
    <tr>
        <td width="381" height="22">
            <p align="right"><span style="font-size:8pt;"><font face="Tahoma" color="#999999">EtchiBoard 
            Gallery System: by EtchiBBS Project.<br> http://etchibbs.kldp.net</font></span></p>
        </td>
    </tr>
</table>
</body>

</html>
<?php
mysql_close($mysql_connect);
 }
}
?>
